use regex_macro::regex;

default_derive!{
    pub struct AttributeAttachment {
        content: String
    }
}

impl TryFrom<&str> for AttributeAttachment {
    type Error = &'static str;

    fn try_from(value: &str) -> Result<Self, Self::Error> {
        let re = regex!("^(?:[A-Za-z0-9+/]{4})*(?:[A-Za-z0-9+/]{2}==|[A-Za-z0-9+/]{3}=)?$");
        if re.is_match(value) {
            Ok(AttributeAttachment { content: String::from(value) })
        }
        else {
            Err("Failed to parse AttributeAttachment")
        }
    }
}

impl Into<String> for AttributeAttachment {
    fn into(self) -> String {
        self.content
    }
}


#[test]
fn forbidden_char() {
    let att: Result<AttributeAttachment, _> = "uqiolgfnluiqoegn&".try_into();
    println!("{:?}", att);
    assert!(att.is_err())
}

#[test]
fn valid1() {
    let att: Result<AttributeAttachment, _> = "".try_into();
    assert_eq!(att, Ok(AttributeAttachment {content: String::from("")}))
}

#[test]
fn valid2() {
    let att: Result<AttributeAttachment, _> = "TWFueSBoYW5kcyBtYWtlIGxpZ2h0IHdvcmsu".try_into();
    assert_eq!(att, Ok(AttributeAttachment{content: String::from("TWFueSBoYW5kcyBtYWtlIGxpZ2h0IHdvcmsu")}))
}
