use phf::phf_set;


default_derive!{
    pub struct AttributeCategory {
        cat: String,
    }
}

impl TryFrom<&str> for AttributeCategory {
    type Error = &'static str;

    fn try_from(value: &str) -> Result<Self, Self::Error> {
        let valid_categories: phf::Set<&'static str> = phf_set!("Internal reference", "Targeting data", "Antivirus detection", "Payload delivery", "Artifacts dropped", "Payload installation", "Persistence mechanism", "Network activity", "Payload type", "Attribution", "External analysis", "Financial fraud", "Support Tool", "Social network", "Person", "Other");
        if value.len() <= 255 && valid_categories.contains(value) {
            Ok(AttributeCategory { cat: value.to_string() })
        }
        else {
            Err("Failed to parse AttributeCategory")
        }
    }
}

impl Into<String> for AttributeCategory {
    fn into(self) -> String {
        self.cat
    }
}


#[test]
fn empty() {
    let cat: Result<AttributeCategory, _> = "".try_into();
    assert!(cat.is_err())
}

#[test]
fn oversized() {
    let cat: Result<AttributeCategory, _> = format!("{:>256}", "Test").as_str().try_into();
    assert!(cat.is_err())
}

#[test]
fn valid1() {
    let cat: Result<AttributeCategory, _> = "Internal reference".try_into();
    assert_eq!(cat, Ok(AttributeCategory { cat: "Internal reference".to_string() }))
}

#[test]
fn valid2() {
    let cat: Result<AttributeCategory, _> = "Person".try_into();
    assert_eq!(cat, Ok(AttributeCategory {cat: String::from("Person")}))
}