
default_derive!{
    pub struct AttributeComment {
        text: String
    }
}

impl TryFrom<&str> for AttributeComment {
    type Error = &'static str;

    fn try_from(value: &str) -> Result<Self, Self::Error> {
        if value.len() <= 65535 {
            Ok(AttributeComment { text: value.to_string() })
        }
        else {
            Err("Failed to parse AttributeComment")
        }
    }
}

impl Into<String> for AttributeComment {
    fn into(self) -> String {
        self.text
    }
}


#[test]
fn oversized() {
    let comment: Result<AttributeComment, _> = format!("{:>65536}", "Test").as_str().try_into();
    assert!(comment.is_err())
}

#[test]
fn valid1() {
    let comment: Result<AttributeComment, _> = "".try_into();
    assert_eq!(comment, Ok(AttributeComment { text: "".to_string() }))
}

#[test]
fn valid2() {
    let comment: Result<AttributeComment, _> = "Comment".try_into();
    assert_eq!(comment, Ok(AttributeComment{text: String::from("Comment")}))
}