use super::UUID;


default_derive!{
    pub struct AttributeEventUUID {
        uuid: String
    }
}

impl TryFrom<&str> for AttributeEventUUID {
    type Error = &'static str;

    fn try_from(value: &str) -> Result<Self, Self::Error> {
        let uuid: Result<UUID, _> = value.try_into();
        match uuid {
            Ok(id) => Ok(AttributeEventUUID{uuid: id.into()}),
            Err(_) => Err("Failed to parse AttributeEventUUID"),
        }
    }
}

impl Into<String> for AttributeEventUUID {
    fn into(self) -> String {
        self.uuid
    }
}

#[test]
fn empty() {
    let uuid: Result<AttributeEventUUID, _> = "".try_into();
    assert!(uuid.is_err())
}

#[test]
fn oversized() {
    let uuid: Result<AttributeEventUUID, _> = format!("{:>37}", "Test").as_str().try_into();
    assert!(uuid.is_err())
}

#[test]
fn valid1() {
    let uuid: Result<AttributeEventUUID, _> = "c99506a6-1255-4b71-afa5-7b8ba48c3b1b".try_into();
    assert_eq!(uuid, Ok(AttributeEventUUID{ uuid: "c99506a6-1255-4b71-afa5-7b8ba48c3b1b".to_string() }))
}
