
default_derive!{
    pub struct AttributeValue {
        value: String
    }
}

impl TryFrom<&str> for AttributeValue {
    type Error = &'static str;

    fn try_from(value: &str) -> Result<Self, Self::Error> {
        if value.len() <= 131071 {
            Ok(AttributeValue { value: value.to_string() })
        }
        else {
            Err("Failed to parse AttributeValue")
        }
    }
}

impl Into<String> for AttributeValue {
    fn into(self) -> String {
        self.value
    }
}


#[test]
fn oversized() {
    let val: Result<AttributeValue, _> = format!("{:>131072}", "Test").as_str().try_into();
    assert!(val.is_err())
}

#[test]
fn valid1() {
    let val: Result<AttributeValue, _> = "".try_into();
    assert_eq!(val, Ok(AttributeValue { value: "".to_string() }))
}

#[test]
fn valid2() {
    let val: Result<AttributeValue, _> = "123456789".try_into();
    assert_eq!(val, Ok(AttributeValue {value: String::from("123456789")}))
}