
default_derive!{
    pub struct EventInfo {
        text: String
    }
}

impl TryFrom<&str> for EventInfo {
    type Error = &'static str;

    fn try_from(value: &str) -> Result<Self, Self::Error> {
        if value.len() <= 65535 {
            Ok(EventInfo { text: value.to_string() })
        }
        else {
            Err("Failed to parse EventInfo")
        }
    }
}

impl Into<String> for EventInfo {
    fn into(self) -> String {
        self.text
    }
}

#[test]
fn oversized() {
    let info: Result<EventInfo, _> = format!("{:>65536}", "Test").as_str().try_into();
    assert!(info.is_err())
}

#[test]
fn valid1() {
    let info: Result<EventInfo, _> = "Informational text".try_into();
    assert_eq!(info, Ok(EventInfo { text: "Informational text".to_string() }))
}