use regex_macro::regex;


default_derive!{
    pub struct UUID {
        id: String
    }
}

impl TryFrom<&str> for UUID {
    type Error = &'static str;

    fn try_from(value: &str) -> Result<Self, Self::Error> {
        let re = regex!("^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$");
        if value.len() <= 36 && re.is_match(value) {
            Ok(UUID { id: value.to_string() })
        }
        else {
            Err("Failed to parse UUID")
        }
    }
}

impl Into<String> for UUID {
    fn into(self) -> String {
        self.id
    }
}

#[test]
fn empty() {
    let uuid: Result<UUID, _> = "".try_into();
    assert!(uuid.is_err())
}

#[test]
fn oversized() {
    let uuid: Result<UUID, _> = format!("{:>37}", "Test").as_str().try_into();
    assert!(uuid.is_err())
}

#[test]
fn valid1() {
    let uuid: Result<UUID, _> = "c99506a6-1255-4b71-afa5-7b8ba48c3b1b".try_into();
    assert_eq!(uuid, Ok(UUID { id: "c99506a6-1255-4b71-afa5-7b8ba48c3b1b".to_string() }))
}
